#
# spec file for package gifsicle
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           gifsicle
Version:        1.95
Release:        1.2
Summary:        Creating and editing GIF images and animations
License:        GPL-2.0-only
Group:          Productivity/Graphics/Other
URL:            https://www.lcdf.org/gifsicle/
Source:         https://www.lcdf.org/gifsicle/%{name}-%{version}.tar.gz
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(x11)
Obsoletes:      ungifsicle < %{version}-%{release}
Provides:       ungifsicle = %{version}-%{release}
%if 0%{?fedora_version} || 0%{?rhel_version} || 0%{?centos_version}
BuildRequires:  perl-Time-HiRes
%define ext_man .gz
%endif

%description
Gifsicle manipulates GIF image files on the
command line. It supports merging several GIFs
into a GIF animation; exploding an animation into
its component frames; changing individual frames
in an animation; turning interlacing on and off;
adding transparency; adding delays, disposals, and
looping to animations; adding or removing
comments; optimizing animations for space; and
changing images' colormaps, among other things.

The gifsicle package contains two other programs:
gifview, a lightweight GIF viewer for X, can show
animations as slideshows or in real time, and
gifdiff compares two GIFs for identical visual
appearance.

%prep
%autosetup

%build
%configure
%make_build

%check
%make_build check

%install
%make_install

%files
%license COPYING
%doc NEWS.md README.md
%{_bindir}/gifdiff
%{_bindir}/gifsicle
%{_bindir}/gifview
%{_mandir}/man1/gifdiff.1%{?ext_man}
%{_mandir}/man1/gifsicle.1%{?ext_man}
%{_mandir}/man1/gifview.1%{?ext_man}

%changelog
* Sun Feb 25 2024 Manfred Schwarb <manfred99@gmx.ch>
- Update to version 1.95:
  * Fix some bugs, including fix for CVE-2023-46009.
* Fri Jun 23 2023 Manfred Schwarb <manfred99@gmx.ch>
- Update to version 1.94:
  * Fix some bugs, including fix for CVE-2023-36193 (bsc#1212645).
* Wed Jun 30 2021 Manfred Schwarb <manfred99@gmx.ch>
- re-introduce make_build macro, as SLE targets are disabled now per default
    for the graphics project
- Update to version 1.93:
  * Fix security bug on certain resize operations with `--resize-method=box`
  * Fix problems with colormapless GIFs.
* Fri Aug 14 2020 Manfred Schwarb <manfred99@gmx.ch>
- unbreak fedora builds
- unbreak SLE_12_SP3_Backports which is still a target for graphics project
- add package group indication, without it we get noisy errors on non-factory targets
* Sun Aug  9 2020 Matthias Eliasson <elimat@opensuse.org>
- Update to version 1.92
  * Add `--lossy` option from Kornel Lipiński.
  * Remove an assertion failure possible with
    `--conserve-memory` + `--colors` + `--careful`.
- Drop fix_gifdiff_null_pointer_deref.patch fixed upstream
- Run spec-cleaner
  * Remove package groups
  * Use make macros
* Mon Apr 16 2018 manfred99@gmx.ch
- add fix_gifdiff_null_pointer_deref.patch:
    upstream fix, commit e2d5c01a9c7022003135888c85b3255226e4cf98
* Fri Jan  5 2018 manfred99@gmx.ch
- drop patches fix_double-free.patch, fix_gifdiff_null-deref.patch
    and fix-null-deref.patch
- upgrade to version 1.91:
  * Several security bug fixes with malicious GIFs.
* Wed Jan  3 2018 manfred99@gmx.ch
- add fix_double-free.patch:
    upstream fix, commit 118a46090c50829dc543179019e6140e1235f909
- add fix_gifdiff_null-deref.patch:
    upstream fix, commit 263cd4519f45bc6ecde74ee280eb1d68ee2de642
* Wed Sep 27 2017 manfred99@gmx.ch
- add fix-null-deref.patch:
    upstream fix, commit f1b8e6323a8fdd029847b7efd400d5fc2ac9aecc
* Fri Aug 18 2017 manfred99@gmx.ch
- drop patch fix_use-after-free.patch
- upgrade to version 1.90:
  * Kill a use-after-free error reported by @junxzm1990.
* Mon Aug 14 2017 manfred99@gmx.ch
- drop SLE 11 support in spec file
* Sun Aug 13 2017 manfred99@gmx.ch
- use spec description of the in-tree spec file.
- add fix_use-after-free.patch:
    upstream fix, commit 81fd7823f6d9c85ab598bc850e40382068361185
- drop following patches:
  * fix-escapes-in-info-mode.patch
  * coverity.patch
  * coverity2.patch
  * document-no-conserve-memory.patch
  * fix-out-of-bound.patch
  * no_status-1_when_valid_output.patch
  * fix_ignore-errors_and_merge_mode.patch
  * initialize_missing_image.patch
  * correct_zero-element_colormaps.patch
- upgrade to version 1.89:
  * Add SIMD support for resizing. When enabled this improves resize
    performance enormously for complex resize methods.
  * Add thread support for resizing. `-j[NTHREADS]` tells gifsicle to use
    up to NTHREADS threads to resize an input image. There are several
    caveats---multiple threads can be only used on unoptimized images.
    Thanks to Github user @wilkesybear.
  * Quashed several crashes and undefined behaviors. Thanks to Github users
    including @pornel, @strazzere, and @b0b0505.
  * Minor bug fixes.
* Mon Jul 10 2017 jengelh@inai.de
- Remove market survey from description.
* Sat Jun 24 2017 manfred99@gmx.ch
- add initialize_missing_image.patch:
    upstream fix, first hunk of commit a0a365136f44e5519f7f486b00a67387f641d0e8
- add correct_zero-element_colormaps.patch:
    upstream fix, commit 1638a43201436f796bdf46d33b87468c089e90b8
* Fri Apr 21 2017 manfred99@gmx.ch
- add no_status-1_when_valid_output.patch:
  upstream fix, commit 0e02f7b62a9a3a344c34f92ddb7e178ad3b3e3ff
- add fix_ignore-errors_and_merge_mode.patch:
  upstream fix, commit 62110e4392230a7e49c339173ee41128ba4ccea9
* Mon Apr 10 2017 manfred99@gmx.ch
- add document-no-conserve-memory.patch:
  upstream fix, commit f27a90731ef1152a106612c4293622736e20e6f8
- fix-out-of-bound.patch:
  upstream fix, commit 1a29f8f5a0e19a2c671eea3604bb43ad0de8c467
* Wed Sep 28 2016 manfred99@gmx.ch
- add coverity.patch:
  upstream fix, commit f679917e8290804ea9ba2d954aedf9caa7e5f142
- add coverity2.patch:
  upstream fix, commit 9ca87d7b1f24e01d30eb41b2304b96131f6c3b53
* Wed Sep 28 2016 manfred99@gmx.ch
- add fix-escapes-in-info-mode.patch:
  upstream fix for github issue #75, commit 2eff5e69e78b9fb28840508e8fc723be115a0167
* Sun Jan 24 2016 mpluskal@suse.com
- Use macro for configure
- Use correct obsoletes/provides
* Fri Jan 22 2016 manfred99@gmx.ch
- update license indication in the spec file: it is GPL-2.0 (only)
* Thu Jan 14 2016 manfred99@gmx.ch
- rpm packaging for OBS
